.. _data:

zero.data
=========

.. currentmodule:: zero.data

.. automodule:: zero.data

.. autosummary::
    :nosignatures:
    :toctree: api
    :template: class.rst

    Enumerate
    FnDataset
    IndexLoader
